# NanoBlogger RSS Feed Plugin

# Limit number of items to include in feed
LIMIT_ITEMS="10"
[ -z "$LIMIT_ITEMS" ] && LIMIT_ITEMS="$MAX_ENTRIES"

NB_RSSModDate=`date "+%Y-%m-%dT%H:%M:%S$BLOG_TZD"`

# escape special characters to help create valid xml feeds
esc_chars(){
	sed -e '/[\&][ ]/ s//\&amp; /g; /[\"]/ s//\&quot;/g'
	}

# make rss feed
make_rssfeed(){
	feed_outfile="$1"
	MKPAGE_OUTFILE="$feed_outfile"
	BLOG_FEED_URL="$BLOG_URL/index.$NB_SYND_FILETYPE"
	[ ! -z "$cat_archfeed" ] && BLOG_FEED_URL="$BLOG_URL/$ARCHIVES/$cat_archfeed"
	cat > "$MKPAGE_OUTFILE" <<-EOF
		<?xml version="1.0" encoding="$BLOG_CHARSET"?>
		<!DOCTYPE rdf:RDF [
		<!ENTITY % HTMLlat1 PUBLIC
		 "-//W3C//ENTITIES Latin 1 for XHTML//EN"
		 "http://www.w3.org/TR/xhtml1/DTD/xhtml-lat1.ent">
		 %HTMLlat1;
		]>
		<rdf:RDF
		 xmlns="http://purl.org/rss/1.0/"
		 xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
		 xmlns:dc="http://purl.org/dc/elements/1.1/"
		 xmlns:content="http://purl.org/rss/1.0/modules/content/"
		 xmlns:admin="http://webns.net/mvcb/"
		>
		<channel rdf:about="$BLOG_FEED_URL">
			<title>$BLOG_TITLE</title>
			<link>$BLOG_URL_MAIN</link>
			<description>$BLOG_DESCRIPTION</description>
			<dc:language>$BLOG_LANG</dc:language>
			<dc:creator>$NB_EntryAuthor</dc:creator>
			<admin:generatorAgent rdf:resource="http://home.columbus.rr.com/n1xt3r/nanoblogger/" />
			<items>
				<rdf:Seq>
					$NB_RSSItems
				</rdf:Seq>
			</items>
		</channel>
		$NB_Entries
		</rdf:RDF>
	EOF
	nb_msg "$MKPAGE_OUTFILE"
	}

# generate feed entries
build_rssfeed(){
	db_catquery="$1"
	query_db limit "$db_catquery" "$LIMIT_ITEMS"
	ARCHIVE_LIST="$DB_RESULTS"
	rss_itemfile="$BLOG_DIR/rss_items.xml"
	> "$rss_itemfile"
	for entry in $ARCHIVE_LIST; do
		NB_EntryTime=`echo "$entry" |sed -e '/\_/ s//\:/g; s/[\.]htm//g'`
	        read_entry "$NB_DATA_DIR/$entry"
		echo '<rdf:li rdf:resource="'$NB_EntryPermalink'" />' >> "$rss_itemfile"
		# non-portable find command!
		#NB_RSSEntryModDate=`find "$NB_DATA_DIR/$entry" -printf "%TY-%Tm-%TdT%TH:%TM:%TS$BLOG_TZD"`
		NB_EntryTitle=`echo "$NB_EntryTitle" |esc_chars`
		RSS_Subject=; cat_title=; oldcat_title=
		for cat_db in $db_categories; do
			cat_var=`grep "$entry" "$NB_DATA_DIR/$cat_db"`
			if [ ! -z "$cat_var" ]; then
				cat_title=`sed -n 1p "$NB_DATA_DIR/$cat_db"`
				[ "$cat_title" != "$oldcat_title" ] && cat_title="$oldcat_title $cat_title"
				oldcat_title="$cat_title,"
			fi
		done
		if [ ! -z "$cat_title" ]; then
			cat_title=`echo $cat_title |sed -e '{$ s/\,[ ]$//g; }' |esc_chars`
			RSS_Subject=`echo '<dc:subject>'$cat_title'</dc:subject>'`
		fi
		#NB_EntryExcerpt=`echo "$NB_EntryBody" |sed -n '1,/^$/p' |esc_chars`
		NB_EntryExcerpt=`echo "$NB_EntryBody" |sed -n '1,/^$/p'`
		cat >> "$BLOG_DIR"/rss_entries.tmp <<-EOF
			<item rdf:about="$NB_EntryPermalink">
				<link>$NB_EntryPermalink</link>
				<title>$NB_EntryTitle</title>
				<dc:date>$NB_EntryTime$BLOG_TZD</dc:date>
				<dc:creator>$NB_EntryAuthor</dc:creator>
				$RSS_Subject
				<description><![CDATA[$NB_EntryExcerpt]]></description>
			</item>
		EOF
	done
	NB_RSSItems=`cat "$rss_itemfile"`
	touch "$BLOG_DIR"/rss_entries.tmp
	NB_Entries=`cat "$BLOG_DIR"/rss_entries.tmp`
	rm -f "$BLOG_DIR"/rss_entries.tmp
	}

# generate category feed entries
build_rss_catfeeds(){
	if [ "$CATEGORY_FEEDS" = "1" ]; then
		nb_msg "generating rss feeds for categories ..."
		db_categories="$CAT_LIST"
		if [ ! -z "$db_categories" ]; then
			for cat_db in $db_categories; do
				if [ -f "$NB_DATA_DIR/$cat_db" ]; then
					cat_archfeed=`chg_suffix "$cat_db" "$NB_SYND_FILETYPE"`
					NB_ArchiveTitle=`sed -n 1p "$NB_DATA_DIR/$cat_db" |esc_chars`
					build_rssfeed "$cat_db"
					make_rssfeed "$BLOG_DIR/$ARCHIVES/$cat_archfeed"
				fi
			done
		fi
	fi
	}

nb_msg "generating rss feed ..."
build_rssfeed nocat
make_rssfeed "$BLOG_DIR/index.$NB_SYND_FILETYPE"
build_rss_catfeeds
rm -f "$rss_itemfile"
